%define lyxver  %(echo %{version} | cut -d. -f1,2)

Name:           lyx
Version:        2.3.6.1
Release:        %mkrel 1
Summary:        A word processor for the Desktop Environment
Group:          Office/Word processor
License:        GPLv2+
URL:            http://www.lyx.org
Source0:        ftp://ftp.lyx.org/pub/lyx/stable/%{lyxver}.x/%{name}-%{version}.tar.xz
Patch0:         lyx-2.3.6-python3.patch

BuildRequires:  bc
BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  dvips
BuildRequires:  gettext-devel
BuildRequires:  ghostscript
BuildRequires:  groff-for-man
BuildRequires:  imagemagick
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  texlive-collection-basic
BuildRequires:  latex
BuildRequires:  magic-devel
# let's build it without hunspell as enchant defaults to hunspell
# building with hunspell doesn't find the dictionary
BuildRequires:  pkgconfig(enchant-2)
BuildRequires:  pkgconfig(ImageMagick)
BuildRequires:  pkgconfig(xpm)
BuildRequires:  sgml-tools
BuildRequires:  texinfo
BuildRequires:  xvkbd
BuildRequires:  locales-en

BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)

Requires:       cmsuper
Requires:       dvips
Requires:       fonts-ttf-latex
Requires:       latex
Requires:       texlive
Requires:       texlive-dist
Requires:       xdg-utils

%description
LyX is a modern approach of writing documents with a computer which breaks
with the tradition of the obsolete typewriter concept.  It is designed for
people who want a professional output with a minimum of time effort, without
becoming specialists in typesetting.  Compared to common word processors LyX
will increase the productivity a lot, since most of the typesetting will be
done by the computer, not the author.  With LyX the author can concentrate on
the contents of their writing, since the computer will take care of the look.

%prep
%autosetup -p1

# Switch to enchant2
sed -i -e '/ENCHANT_LIBRARY/s,"enchant","enchant-2",g' \
  -e 's,/usr/include/enchant,%{_includedir}/enchant-2,g' \
   development/cmake/modules/FindENCHANT.cmake

%build
%cmake_qt5 \
 -G"Unix Makefiles"  \
 -DLYX_EXTERNAL_BOOST=ON \
 -DLYX_ENCHANT=ON \
 -DLYX_RELEASE=OFF \
 -DLYX_PACKAGE_SUFFIX=OFF \
 -DLYX_PROGRAM_SUFFIX=OFF

cp -af po/* build/po/

%cmake_build

%install
%cmake_install

## Set up the lyx-specific class files where TeX can see then
TEXMF=%{_datadir}/texmf
mkdir -p %{buildroot}${TEXMF}/tex/latex
mv %{buildroot}%{_datadir}/%{name}/tex %{buildroot}${TEXMF}/tex/latex/%{name}

%find_lang %{name}

# icon
install -p -D -m644 lib/images/lyx.png \
  %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/lyx.png

install -p -D -m644 lib/images/lyx.svg \
  %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/lyx.svg

# ghost'd files
touch %{buildroot}%{_datadir}/lyx/lyxrc.defaults
touch %{buildroot}%{_datadir}/lyx/{packages,textclass}.lst

# fonts
install -m 0755 -d %{buildroot}%{_fontdir}
mv %{buildroot}%{_datadir}/lyx/fonts/*.ttf %{buildroot}%{_fontdir}/
rm -rf %{buildroot}%{_datadir}/lyx/fonts

## Now configure LyX
pushd %{buildroot}%{_datadir}/%{name}
%{__python3} configure.py > /dev/null
## Remove buildroot definition
sed -i -e 's,%{buildroot},,g' configure.log
popd

# bash completion
install -p -D -m 0644 lib/scripts/bash_completion %{buildroot}%{_sysconfdir}/bash_completion.d/%{name}

%check
desktop-file-validate %{buildroot}%{_datadir}/applications/%{name}.desktop
# tests/test_filetools error bogus ( see http://bugzilla.redhat.com/723938 )
make -C build -k check ||:

%postun
if [ $1 -eq 0 ] ; then
  texhash >& /dev/null
fi

%posttrans
texhash >& /dev/null

%files -f %{name}.lang
%doc README{,.*} ANNOUNCE RELEASE-NOTES
%{_bindir}/%{name}
%{_bindir}/lyxclient
%{_bindir}/tex2lyx
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/texmf/tex/latex/%{name}
%{_sysconfdir}/bash_completion.d/%{name}
%{_iconsdir}/hicolor/scalable/apps/%{name}.svg
%{_iconsdir}/hicolor/48x48/apps/%{name}.png


%changelog
* Tue Jan 26 2021 akien <akien> 2.3.6.1-1.mga8
+ Revision: 1673412
- Version 2.3.6.1

* Wed Dec 30 2020 akien <akien> 2.3.6-1.mga8
+ Revision: 1665676
- Version 2.3.6

* Thu Dec 17 2020 umeabot <umeabot> 2.3.5.2-2.mga8
+ Revision: 1659051
- Rebuild for new Qt5

* Fri Sep 18 2020 joequant <joequant> 2.3.5.2-1.mga8
+ Revision: 1628414
- update to 2.3.5.2

* Sun May 24 2020 wally <wally> 2.3.4.3-4.mga8
+ Revision: 1587377
- BR locales-en to suppress build time warnings

* Sun May 24 2020 wally <wally> 2.3.4.3-3.mga8
+ Revision: 1587295
- remove buildroot definition from built files
- build with python3

* Thu Feb 20 2020 umeabot <umeabot> 2.3.4.3-2.mga8
+ Revision: 1545192
- Mageia 8 Mass Rebuild

* Tue Feb 18 2020 daviddavid <daviddavid> 2.3.4.3-1.mga8
+ Revision: 1540940
- new version: 2.3.4.3

* Mon Jan 27 2020 daviddavid <daviddavid> 2.3.4-1.mga8
+ Revision: 1484189
- new version: 2.3.4
+ wally <wally>
- build with new cmake macros

* Sun Mar 31 2019 umeabot <umeabot> 2.3.1-3.mga7
+ Revision: 1383302
- Qt5 Rebuild

* Sat Feb 23 2019 wally <wally> 2.3.1-2.mga7
+ Revision: 1369509
- switch to enchant2

* Fri Oct 19 2018 akien <akien> 2.3.1-1.mga7
+ Revision: 1322338
- Version 2.3.1

* Sun Sep 23 2018 umeabot <umeabot> 2.3.0-3.mga7
+ Revision: 1299421
- Mageia 7 Mass Rebuild

* Sat Jul 21 2018 wally <wally> 2.3.0-2.mga7
+ Revision: 1244684
- add upstream patches to fix build with Qt >= 5.11

* Sat Mar 03 2018 kekepower <kekepower> 2.3.0-1.mga7
+ Revision: 1206172
- Update to version 2.3.0
- Using cmake instead of configure
- Fixed file list

* Mon Dec 25 2017 wally <wally> 2.2.3-4.mga7
+ Revision: 1184759
- rebuild for new boost

* Sun Nov 19 2017 tv <tv> 2.2.3-3.mga7
+ Revision: 1177747
- rebuild for boost 1.65

* Sat Sep 16 2017 tv <tv> 2.2.3-2.mga7
+ Revision: 1154528
- rebuild with latest boost

* Sat May 20 2017 akien <akien> 2.2.3-1.mga6
+ Revision: 1103489
- Version 2.2.3

* Mon Dec 05 2016 akien <akien> 2.2.2-1.mga6
+ Revision: 1072644
- Drop P50: Upstream hasn't cared about using xdg-open since 6 years, let's stop caring too
- Version 2.2.2

* Wed Oct 05 2016 tv <tv> 2.2.1-2.mga6
+ Revision: 1058992
- disable some warnings
- install bash_completion configuration file
- add %%check section
- use upstream desktop entry instead of our own

* Thu Aug 11 2016 akien <akien> 2.2.1-1.mga6
+ Revision: 1045758
- Cleanup %%install section
- Version 2.2.1

* Wed Jul 13 2016 tmb <tmb> 2.2.0-3.mga6
+ Revision: 1041937
- submit to release
+ tv <tv>
- remove useless option

* Wed Jul 13 2016 tv <tv> 2.2.0-2.mga6
+ Revision: 1041897
- BR pkgconfig(Qt5Concurrent) & switch back to Qt5

* Tue Jul 12 2016 tv <tv> 2.2.0-1.mga6
+ Revision: 1041259
- switch back to Qt4 as it does compile
- new release (mga#18907)
- build with Qt5

* Sat Dec 26 2015 daviddavid <daviddavid> 2.1.4-4.mga6
+ Revision: 915372
- rebuild for new boost 1.60.0

* Sat Sep 26 2015 fwang <fwang> 2.1.4-3.mga6
+ Revision: 883774
- rebuild for new boost

* Sat Aug 29 2015 cjw <cjw> 2.1.4-2.mga6
+ Revision: 870918
- rebuild with gcc 5

* Tue Aug 04 2015 spuhler <spuhler> 2.1.4-1.mga6
+ Revision: 861117
- update xdg_open.patch
- upgrade to vers. 2.1.4

* Sun Aug 02 2015 daviddavid <daviddavid> 2.1.3-2.mga6
+ Revision: 860582
- rebuild for new boost-1.58.0

* Sun Feb 22 2015 spuhler <spuhler> 2.1.3-1.mga5
+ Revision: 816330
- upgrade to vers. 2.1.3
  * fixes Bug #15339

* Mon Dec 15 2014 spuhler <spuhler> 2.1.2-2.mga5
+ Revision: 803215
- adding Requires: textlive-dist

* Mon Nov 03 2014 spuhler <spuhler> 2.1.2-1.mga5
+ Revision: 795311
- rediffed xdg patch
- upgrade to vers. 2.1.2
 * fixes bug #14429

* Wed Oct 15 2014 umeabot <umeabot> 2.1.1-3.mga5
+ Revision: 739566
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.1.1-2.mga5
+ Revision: 682106
- Mageia 5 Mass Rebuild

* Tue Jul 15 2014 fwang <fwang> 2.1.1-1.mga5
+ Revision: 652811
- 2.1.1

* Sat Jun 14 2014 barjac <barjac> 2.1.0-1.mga5
+ Revision: 636050
- add BuildRequires bc and magic-devel
+ spuhler <spuhler>
- changed BuildRequires:	libmagick-devel to magick-devel
-update to ver. 2.1.0
  * lots of spec file changes
- rediffed xdg patch

* Fri Apr 25 2014 fwang <fwang> 2.0.8-1.mga5
+ Revision: 617734
- 2.0.8

* Thu Feb 06 2014 spuhler <spuhler> 2.0.7-1.mga5
+ Revision: 583987
- upgrade to ver. 2.0.7

* Sat Oct 19 2013 umeabot <umeabot> 2.0.6-3.mga4
+ Revision: 529537
- Mageia 4 Mass Rebuild

* Wed Jul 10 2013 fwang <fwang> 2.0.6-2.mga4
+ Revision: 452376
- rebuild for new boost

* Thu May 23 2013 spuhler <spuhler> 2.0.6-1.mga4
+ Revision: 425421
- upgrade to 2.0.6
- replaced patches accordingly

* Thu Apr 11 2013 spuhler <spuhler> 2.0.5.1-3.mga3
+ Revision: 409593
- bumped rel for rebuild against boost-1.53

* Sat Jan 12 2013 umeabot <umeabot> 2.0.5.1-2.mga3
+ Revision: 359224
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Jan 03 2013 fwang <fwang> 2.0.5.1-1.mga3
+ Revision: 337964
- new version 2.0.5.1

* Thu Dec 20 2012 fwang <fwang> 2.0.5-2.mga3
+ Revision: 333051
- rebuild for new boost

* Mon Nov 12 2012 fwang <fwang> 2.0.5-1.mga3
+ Revision: 317102
- update rpm group
- new version 2.0.5

* Tue Jul 31 2012 fwang <fwang> 2.0.4-2.mga3
+ Revision: 276700
- rebuild for new boost

* Sat Jun 30 2012 fwang <fwang> 2.0.4-1.mga3
+ Revision: 265237
- new version 2.0.4

* Wed May 30 2012 fwang <fwang> 2.0.3-4.mga3
+ Revision: 250118
- do not set locale based dir

* Wed May 30 2012 fwang <fwang> 2.0.3-3.mga3
+ Revision: 250104
- rebuild for new boost

* Wed Mar 14 2012 spuhler <spuhler> 2.0.3-2.mga2
+ Revision: 223315
- build without hunspell as enchant defaults to hunspell by itself

* Wed Feb 29 2012 fwang <fwang> 2.0.3-1.mga2
+ Revision: 215978
- new version 2.0.3

* Wed Nov 30 2011 fwang <fwang> 2.0.2-1.mga2
+ Revision: 174348
- new version 2.0.2

* Mon Nov 28 2011 fwang <fwang> 2.0.1-3.mga2
+ Revision: 173612
- rebuild for new boost

* Tue Sep 06 2011 schultz <schultz> 2.0.1-2.mga2
+ Revision: 139759
- Remove gender bias from description

* Tue Sep 06 2011 fwang <fwang> 2.0.1-1.mga2
+ Revision: 139641
- new version 2.0.1
- rebuild for new boost

* Sun Jun 26 2011 fwang <fwang> 2.0.0-3.mga2
+ Revision: 113999
- rebuild for new hunspell

* Wed Jun 22 2011 fwang <fwang> 2.0.0-2.mga2
+ Revision: 111915
- rebuild for new boost

* Thu Jun 16 2011 tv <tv> 2.0.0-1.mga2
+ Revision: 108511
- new version 2.0.0
- br gettext
- use xz tarball

* Tue Apr 26 2011 wally <wally> 1.6.8-3.mga1
+ Revision: 91768
- fix desktop file name (mga#954)
- fix exec line on desktop file

* Fri Mar 04 2011 boklm <boklm> 1.6.8-2.mga1
+ Revision: 64176
- use texlive instead of tetex

* Thu Feb 10 2011 spuhler <spuhler> 1.6.8-1.mga1
+ Revision: 49629
-cd %%_datadir/lyx
  +cd %%{buildroot}%%_datadir/lyx
-#%%_datadir/%%name
  +%%_datadir/%%name
- removed buildroot definition from .spec
  removed the if mdkversion lines
- imported package lyx

